<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use App\Models\Client;
use App\Models\Invoice;
use App\Models\Transfer;
use App\Models\Purchase;

class DashboardController extends Controller
{
    /**
     * Display the dashboard with summary data.
     *
     * @return \Illuminate\View\View
     */
    public function index()
    {
        // Get counts for dashboard cards
        $clientCount = Client::count();
        $invoiceCount = Invoice::count();
        $transferCount = Transfer::count();
        $purchaseCount = Purchase::count();
        
        // Get recent invoices
        $recentInvoices = Invoice::with('client')
                            ->latest()
                            ->take(5)
                            ->get();
        
        // Get recent transfers
        $recentTransfers = Transfer::with('invoice.client')
                            ->latest()
                            ->take(5)
                            ->get();
        
        // Calculate financial summaries
        $currentYear = date('Y');
        $previousYear = $currentYear - 1;
        
        $currentYearPurchases = Purchase::where('year', $currentYear)
                                ->sum('total_amount');
        $previousYearPurchases = Purchase::where('year', $previousYear)
                                ->sum('total_amount');
        
        return view('dashboard', compact(
            'clientCount', 
            'invoiceCount', 
            'transferCount', 
            'purchaseCount',
            'recentInvoices',
            'recentTransfers',
            'currentYear',
            'previousYear',
            'currentYearPurchases',
            'previousYearPurchases'
        ));
    }
}