<?php

namespace App\Http\Controllers;

use App\Models\Purchase;
use Illuminate\Http\Request;

class PurchaseController extends Controller
{
    public function index()
    {
        $currentYear = date('Y');
        $previousYear = $currentYear - 1;
        
        $currentYearPurchases = Purchase::where('year', $currentYear)->sum('total_amount');
        $previousYearPurchases = Purchase::where('year', $previousYear)->sum('total_amount');
        
        $purchases = Purchase::latest()->paginate(10);
        
        return view('purchases.index', compact('purchases', 'currentYearPurchases', 'previousYearPurchases', 'currentYear', 'previousYear'));
    }

    public function create()
    {
        return view('purchases.create');
    }

    public function store(Request $request)
    {
        $validated = $request->validate([
            'supplier_name' => 'required|string|max:255',
            'invoice_number' => 'required|string|max:255',
            'invoice_date' => 'required|date',
            'invoice_weight' => 'required|numeric|min:0',
            'jewelry_type' => 'nullable|string|max:255',
            'alloy' => 'nullable|string|max:255',
            'total_amount' => 'required|numeric|min:0',
            'transfer_status' => 'required|string|max:255',
            'transfer_date' => 'nullable|date',
            'receipt_date' => 'nullable|date',
        ]);
        
        // Add the year field
        $validated['year'] = date('Y', strtotime($validated['invoice_date']));
        
        Purchase::create($validated);

        return redirect()->route('purchases.index')
            ->with('success', 'Purchase created successfully.');
    }

    public function show(Purchase $purchase)
    {
        return view('purchases.show', compact('purchase'));
    }

    public function edit(Purchase $purchase)
    {
        return view('purchases.edit', compact('purchase'));
    }

    public function update(Request $request, Purchase $purchase)
    {
        $validated = $request->validate([
            'supplier_name' => 'required|string|max:255',
            'invoice_number' => 'required|string|max:255',
            'invoice_date' => 'required|date',
            'invoice_weight' => 'required|numeric|min:0',
            'jewelry_type' => 'nullable|string|max:255',
            'alloy' => 'nullable|string|max:255',
            'total_amount' => 'required|numeric|min:0',
            'transfer_status' => 'required|string|max:255',
            'transfer_date' => 'nullable|date',
            'receipt_date' => 'nullable|date',
        ]);
        
        // Update the year field
        $validated['year'] = date('Y', strtotime($validated['invoice_date']));
        
        $purchase->update($validated);

        return redirect()->route('purchases.index')
            ->with('success', 'Purchase updated successfully.');
    }

    public function destroy(Purchase $purchase)
    {
        $purchase->delete();

        return redirect()->route('purchases.index')
            ->with('success', 'Purchase deleted successfully.');
    }
}