<?php

namespace App\Http\Controllers;

use App\Models\Transfer;
use App\Models\Invoice;
use Illuminate\Http\Request;

class TransferController extends Controller
{
    public function index()
    {
        $transfers = Transfer::with('invoice.client')->latest()->paginate(10);
        return view('transfers.index', compact('transfers'));
    }

    public function create()
    {
        $invoices = Invoice::where('payment_type', 'transfer')->doesntHave('transfers')->get();
        return view('transfers.create', compact('invoices'));
    }

    public function store(Request $request)
    {
        $validated = $request->validate([
            'invoice_id' => 'required|exists:invoices,id',
            'transfer_date' => 'required|date',
            'receipt_date' => 'nullable|date',
            'status' => 'required|string',
            'notes' => 'nullable|string',
        ]);

        Transfer::create($validated);

        return redirect()->route('transfers.index')
            ->with('success', 'Transfer created successfully.');
    }

    public function show(Transfer $transfer)
    {
        $transfer->load('invoice.client');
        return view('transfers.show', compact('transfer'));
    }

    public function edit(Transfer $transfer)
    {
        $invoices = Invoice::where('payment_type', 'transfer')->get();
        return view('transfers.edit', compact('transfer', 'invoices'));
    }

    public function update(Request $request, Transfer $transfer)
    {
        $validated = $request->validate([
            'invoice_id' => 'required|exists:invoices,id',
            'transfer_date' => 'required|date',
            'receipt_date' => 'nullable|date',
            'status' => 'required|string',
            'notes' => 'nullable|string',
        ]);

        $transfer->update($validated);

        return redirect()->route('transfers.index')
            ->with('success', 'Transfer updated successfully.');
    }

    public function destroy(Transfer $transfer)
    {
        $transfer->delete();

        return redirect()->route('transfers.index')
            ->with('success', 'Transfer deleted successfully.');
    }
}