<?php
namespace App\Models;

use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;

class Invoice extends Model
{
    use HasFactory;

    protected $fillable = [
        'invoice_number',
        'client_id',
        'invoice_date',
        'payment_type',
        'gold_price',
        'total_weight',
        'total_amount',
        'total_gold',
        'total_fees',
        'grand_total',
        'authorized_signature',
        'client_signature',
        'status',
    ];

    protected $casts = [
        'invoice_date' => 'date',
    ];

    public function client()
    {
        return $this->belongsTo(Client::class);
    }

    public function items()
    {
        return $this->hasMany(InvoiceItem::class);
    }

    public function transfers()
    {
        return $this->hasMany(Transfer::class);
    }
    
    public function calculateTotals()
    {
        $this->total_weight = $this->items->sum('weight');
        $this->total_fees = $this->items->sum('fees');
        $this->total_gold = $this->items->sum(function ($item) {
            return $item->weight * $this->gold_price;
        });
        $this->total_amount = $this->total_gold + $this->total_fees;
        $this->grand_total = $this->total_amount;
        
        return $this;
    }
}