document.addEventListener('DOMContentLoaded', function() {
    // Invoice item management
    const itemsContainer = document.getElementById('items-container');
    const addItemButton = document.getElementById('add-item');
    const goldPriceInput = document.getElementById('gold_price');
    
    let itemCounter = document.querySelectorAll('.invoice-item').length || 0;
    
    // Add new item row
    if (addItemButton) {
        addItemButton.addEventListener('click', function(e) {
            e.preventDefault(); // Prevent form submission
            addNewItem();
        });
    }
    
    // Initialize calculation for existing items
    document.querySelectorAll('.invoice-item').forEach(item => {
        setupItemEvents(item);
    });
    
    // Calculate totals on page load
    calculateInvoiceTotals();
    
    function addNewItem() {
        const newItem = document.createElement('div');
        newItem.className = 'invoice-item bg-gray-50 p-4 rounded mb-4';
        newItem.dataset.index = itemCounter++;
        
        newItem.innerHTML = `
            <div class="flex justify-between mb-2">
                <h4 class="font-bold">البند #${itemCounter}</h4>
                <button type="button" class="remove-item text-red-500 hover:text-red-700">
                    <svg xmlns="http://www.w3.org/2000/svg" class="h-5 w-5" viewBox="0 0 20 20" fill="currentColor">
                        <path fill-rule="evenodd" d="M9 2a1 1 0 00-.894.553L7.382 4H4a1 1 0 000 2v10a2 2 0 002 2h8a2 2 0 002-2V6a1 1 0 100-2h-3.382l-.724-1.447A1 1 0 0011 2H9zM7 8a1 1 0 012 0v6a1 1 0 11-2 0V8zm5-1a1 1 0 00-1 1v6a1 1 0 102 0V8a1 1 0 00-1-1z" clip-rule="evenodd" />
                    </svg>
                </button>
            </div>
            <div class="grid grid-cols-1 md:grid-cols-2 gap-4">
                <div>
                    <label class="block text-sm font-medium text-gray-700 mb-1">التفاصيل</label>
                    <input type="text" name="items[${itemCounter-1}][details]" class="item-details shadow appearance-none border rounded w-full py-2 px-3 text-gray-700 leading-tight focus:outline-none focus:shadow-outline" required>
                </div>
                <div>
                    <label class="block text-sm font-medium text-gray-700 mb-1">العيار</label>
                    <input type="text" name="items[${itemCounter-1}][caliber]" class="item-caliber shadow appearance-none border rounded w-full py-2 px-3 text-gray-700 leading-tight focus:outline-none focus:shadow-outline" required>
                </div>
                <div>
                    <label class="block text-sm font-medium text-gray-700 mb-1">الوزن</label>
                    <input type="number" step="0.001" name="items[${itemCounter-1}][weight]" class="item-weight shadow appearance-none border rounded w-full py-2 px-3 text-gray-700 leading-tight focus:outline-none focus:shadow-outline" required>
                </div>
                <div>
                    <label class="block text-sm font-medium text-gray-700 mb-1">الأجرة</label>
                    <input type="number" step="0.01" name="items[${itemCounter-1}][fees]" class="item-fees shadow appearance-none border rounded w-full py-2 px-3 text-gray-700 leading-tight focus:outline-none focus:shadow-outline" required>
                </div>
            </div>
            <div class="mt-3">
                <label class="block text-sm font-medium text-gray-700 mb-1">المجموع</label>
                <input type="number" step="0.01" name="items[${itemCounter-1}][total]" class="item-total shadow appearance-none border rounded w-full py-2 px-3 text-gray-700 leading-tight focus:outline-none focus:shadow-outline bg-gray-100" readonly>
            </div>
        `;
        
        itemsContainer.appendChild(newItem);
        setupItemEvents(newItem);
    }
    
    function setupItemEvents(item) {
        const weightInput = item.querySelector('.item-weight');
        const feesInput = item.querySelector('.item-fees');
        const removeButton = item.querySelector('.remove-item');
        
        // Calculate item total when inputs change
        weightInput?.addEventListener('input', function() {
            calculateItemTotal(item);
        });
        
        feesInput?.addEventListener('input', function() {
            calculateItemTotal(item);
        });
        
        goldPriceInput?.addEventListener('input', function() {
            // Recalculate all items when gold price changes
            document.querySelectorAll('.invoice-item').forEach(item => {
                calculateItemTotal(item);
            });
        });
        
        // Remove item
        removeButton?.addEventListener('click', function() {
            item.remove();
            calculateInvoiceTotals();
        });
    }
    
    function calculateItemTotal(item) {
        const weightInput = item.querySelector('.item-weight');
        const feesInput = item.querySelector('.item-fees');
        const totalInput = item.querySelector('.item-total');
        
        if (weightInput && feesInput && totalInput && goldPriceInput) {
            const weight = parseFloat(weightInput.value) || 0;
            const fees = parseFloat(feesInput.value) || 0;
            const goldPrice = parseFloat(goldPriceInput.value) || 0;
            
            const total = (weight * goldPrice) + fees;
            totalInput.value = total.toFixed(2);
            
            calculateInvoiceTotals();
        }
    }
    
    function calculateInvoiceTotals() {
        const itemElements = document.querySelectorAll('.invoice-item');
        const totalWeightElement = document.getElementById('total_weight');
        const totalFeesElement = document.getElementById('total_fees');
        const totalGoldElement = document.getElementById('total_gold');
        const grandTotalElement = document.getElementById('grand_total');
        
        if (!totalWeightElement || !totalFeesElement || !totalGoldElement || !grandTotalElement) {
            return;
        }
        
        let totalWeight = 0;
        let totalFees = 0;
        let totalGold = 0;
        let grandTotal = 0;
        
        itemElements.forEach(item => {
            const weightInput = item.querySelector('.item-weight');
            const feesInput = item.querySelector('.item-fees');
            
            if (weightInput && feesInput) {
                const weight = parseFloat(weightInput.value) || 0;
                const fees = parseFloat(feesInput.value) || 0;
                const goldPrice = parseFloat(goldPriceInput.value) || 0;
                
                totalWeight += weight;
                totalFees += fees;
                totalGold += (weight * goldPrice);
                grandTotal += (weight * goldPrice) + fees;
            }
        });
        
        totalWeightElement.value = totalWeight.toFixed(3);
        totalFeesElement.value = totalFees.toFixed(2);
        totalGoldElement.value = totalGold.toFixed(2);
        grandTotalElement.value = grandTotal.toFixed(2);
    }
});