<x-app-layout>
    <x-slot name="header">
        <h2 class="font-semibold text-xl text-gray-800 leading-tight">
            {{ __('إنشاء فاتورة جديدة') }}
        </h2>
    </x-slot>

    <div class="py-12">
        <div class="max-w-7xl mx-auto sm:px-6 lg:px-8">
            <div class="bg-white overflow-hidden shadow-sm sm:rounded-lg">
                <div class="p-6 bg-white border-b border-gray-200">
                    @if (session('error'))
                        <div class="bg-red-100 border border-red-400 text-red-700 px-4 py-3 rounded relative mb-4" role="alert">
                            <span class="block sm:inline">{{ session('error') }}</span>
                        </div>
                    @endif

                    <form method="POST" action="{{ route('invoices.store') }}">
                        @csrf

                        <div class="grid grid-cols-1 md:grid-cols-2 gap-4 mb-6">
                            <div>
                                <label for="invoice_number" class="block text-gray-700 text-sm font-bold mb-2">{{ __('رقم الفاتورة') }}</label>
                                <input id="invoice_number" type="text" class="shadow appearance-none border rounded w-full py-2 px-3 text-gray-700 leading-tight focus:outline-none focus:shadow-outline @error('invoice_number') border-red-500 @enderror" name="invoice_number" value="{{ old('invoice_number', $invoice_number ?? 'INV-' . date('Ymd') . '-' . rand(1000, 9999)) }}" required>
                                @error('invoice_number')
                                    <p class="text-red-500 text-xs italic mt-1">{{ $message }}</p>
                                @enderror
                            </div>

                            <div>
                                <label for="client_id" class="block text-gray-700 text-sm font-bold mb-2">{{ __('الزبون') }}</label>
                                <select id="client_id" class="shadow appearance-none border rounded w-full py-2 px-3 text-gray-700 leading-tight focus:outline-none focus:shadow-outline @error('client_id') border-red-500 @enderror" name="client_id" required>
                                    <option value="">{{ __('اختر الزبون') }}</option>
                                    @foreach($clients as $client)
                                        <option value="{{ $client->id }}" {{ old('client_id') == $client->id ? 'selected' : '' }}>{{ $client->name }}</option>
                                    @endforeach
                                </select>
                                @error('client_id')
                                    <p class="text-red-500 text-xs italic mt-1">{{ $message }}</p>
                                @enderror
                            </div>

                            <div>
                                <label for="invoice_date" class="block text-gray-700 text-sm font-bold mb-2">{{ __('تاريخ الفاتورة') }}</label>
                                <input id="invoice_date" type="date" class="shadow appearance-none border rounded w-full py-2 px-3 text-gray-700 leading-tight focus:outline-none focus:shadow-outline @error('invoice_date') border-red-500 @enderror" name="invoice_date" value="{{ old('invoice_date', date('Y-m-d')) }}" required>
                                @error('invoice_date')
                                    <p class="text-red-500 text-xs italic mt-1">{{ $message }}</p>
                                @enderror
                            </div>

                            <div>
                                <label for="payment_type" class="block text-gray-700 text-sm font-bold mb-2">{{ __('طريقة الدفع') }}</label>
                                <select id="payment_type" class="shadow appearance-none border rounded w-full py-2 px-3 text-gray-700 leading-tight focus:outline-none focus:shadow-outline @error('payment_type') border-red-500 @enderror" name="payment_type" required>
                                    <option value="cash" {{ old('payment_type') == 'cash' ? 'selected' : '' }}>{{ __('نقدي') }}</option>
                                    <option value="transfer" {{ old('payment_type') == 'transfer' ? 'selected' : '' }}>{{ __('تحويل') }}</option>
                                    <option value="credit" {{ old('payment_type') == 'credit' ? 'selected' : '' }}>{{ __('آجل') }}</option>
                                </select>
                                @error('payment_type')
                                    <p class="text-red-500 text-xs italic mt-1">{{ $message }}</p>
                                @enderror
                            </div>

                            <div>
                                <label for="gold_price" class="block text-gray-700 text-sm font-bold mb-2">{{ __('سعر الذهب') }}</label>
                                <input id="gold_price" type="number" step="0.01" class="shadow appearance-none border rounded w-full py-2 px-3 text-gray-700 leading-tight focus:outline-none focus:shadow-outline @error('gold_price') border-red-500 @enderror" name="gold_price" value="{{ old('gold_price') }}" required>
                                @error('gold_price')
                                    <p class="text-red-500 text-xs italic mt-1">{{ $message }}</p>
                                @enderror
                            </div>

                            <div>
                                <label for="authorized_signature" class="block text-gray-700 text-sm font-bold mb-2">{{ __('توقيع المدير المفوض') }}</label>
                                <input id="authorized_signature" type="text" class="shadow appearance-none border rounded w-full py-2 px-3 text-gray-700 leading-tight focus:outline-none focus:shadow-outline @error('authorized_signature') border-red-500 @enderror" name="authorized_signature" value="{{ old('authorized_signature', 'علي نزار محمد') }}">
                                @error('authorized_signature')
                                    <p class="text-red-500 text-xs italic mt-1">{{ $message }}</p>
                                @enderror
                            </div>
                        </div>

                        <div class="mb-6">
                            <h3 class="text-lg font-bold mb-2">{{ __('بنود الفاتورة') }}</h3>
                            
                            <div id="items-container">
                                <!-- JavaScript will add items here -->
                            </div>
                            
                            <button type="button" id="add-item" class="mt-4 bg-green-500 hover:bg-green-700 text-white font-bold py-2 px-4 rounded focus:outline-none focus:shadow-outline">
                                {{ __('إضافة بند') }}
                            </button>
                        </div>

                        <div class="bg-gray-100 p-4 rounded-lg mb-6">
                            <h3 class="text-lg font-bold mb-4">{{ __('ملخص الفاتورة') }}</h3>
                            
                            <div class="grid grid-cols-1 md:grid-cols-3 gap-4">
                                <div>
                                    <label for="total_weight" class="block text-gray-700 text-sm font-bold mb-2">{{ __('إجمالي الوزن') }}</label>
                                    <input id="total_weight" type="text" class="shadow appearance-none border rounded w-full py-2 px-3 text-gray-700 leading-tight focus:outline-none focus:shadow-outline bg-gray-100" name="total_weight" readonly>
                                </div>
                                
                                <div>
                                    <label for="total_fees" class="block text-gray-700 text-sm font-bold mb-2">{{ __('إجمالي الأجور') }}</label>
                                    <input id="total_fees" type="text" class="shadow appearance-none border rounded w-full py-2 px-3 text-gray-700 leading-tight focus:outline-none focus:shadow-outline bg-gray-100" name="total_fees" readonly>
                                </div>
                                
                                <div>
                                    <label for="total_gold" class="block text-gray-700 text-sm font-bold mb-2">{{ __('إجمالي الذهب') }}</label>
                                    <input id="total_gold" type="text" class="shadow appearance-none border rounded w-full py-2 px-3 text-gray-700 leading-tight focus:outline-none focus:shadow-outline bg-gray-100" name="total_gold" readonly>
                                </div>
                                
                                <div class="md:col-span-3">
                                    <label for="grand_total" class="block text-gray-700 text-sm font-bold mb-2">{{ __('المبلغ الإجمالي') }}</label>
                                    <input id="grand_total" type="text" class="shadow appearance-none border rounded w-full py-2 px-3 text-gray-700 font-bold text-lg leading-tight focus:outline-none focus:shadow-outline bg-gray-100" name="grand_total" readonly>
                                </div>
                            </div>
                        </div>

                        <div class="flex items-center justify-between">
                            <button type="submit" class="bg-blue-500 hover:bg-blue-700 text-white font-bold py-2 px-4 rounded focus:outline-none focus:shadow-outline">
                                {{ __('إنشاء الفاتورة') }}
                            </button>
                            <a href="{{ route('invoices.index') }}" class="inline-block align-baseline font-bold text-sm text-blue-500 hover:text-blue-800">
                                {{ __('إلغاء') }}
                            </a>
                        </div>
                    </form>
                </div>
            </div>
        </div>
    </div>

    <script src="{{ asset('js/invoice.js') }}"></script>
    <script>
        // Trigger adding first item on page load
        document.addEventListener('DOMContentLoaded', function() {
            // Wait a moment to ensure all DOM elements are ready
            setTimeout(function() {
                document.getElementById('add-item').click();
            }, 100);
        });
    </script>
</x-app-layout>