<x-app-layout>
    <x-slot name="header">
        <h2 class="font-semibold text-xl text-gray-800 leading-tight">
            {{ __('إنشاء حوالة جديدة') }}
        </h2>
    </x-slot>

    <div class="py-12">
        <div class="max-w-7xl mx-auto sm:px-6 lg:px-8">
            <div class="bg-white overflow-hidden shadow-sm sm:rounded-lg">
                <div class="p-6 bg-white border-b border-gray-200">
                    @if (session('error'))
                        <div class="bg-red-100 border border-red-400 text-red-700 px-4 py-3 rounded relative mb-4" role="alert">
                            <span class="block sm:inline">{{ session('error') }}</span>
                        </div>
                    @endif

                    <form method="POST" action="{{ route('transfers.store') }}">
                        @csrf

                        <div class="mb-4">
                            <label for="invoice_id" class="block text-gray-700 text-sm font-bold mb-2">{{ __('الفاتورة') }}</label>
                            <select id="invoice_id" class="shadow appearance-none border rounded w-full py-2 px-3 text-gray-700 leading-tight focus:outline-none focus:shadow-outline @error('invoice_id') border-red-500 @enderror" name="invoice_id" required>
                                <option value="">{{ __('اختر الفاتورة') }}</option>
                                @foreach($invoices as $invoice)
                                    <option value="{{ $invoice->id }}" {{ old('invoice_id') == $invoice->id ? 'selected' : '' }}>
                                        {{ $invoice->invoice_number }} - {{ $invoice->client->name }} - {{ number_format($invoice->grand_total, 2) }}
                                    </option>
                                @endforeach
                            </select>
                            @error('invoice_id')
                                <p class="text-red-500 text-xs italic mt-1">{{ $message }}</p>
                            @enderror
                        </div>

                        <div class="mb-4">
                            <label for="transfer_date" class="block text-gray-700 text-sm font-bold mb-2">{{ __('تاريخ التحويل') }}</label>
                            <input id="transfer_date" type="date" class="shadow appearance-none border rounded w-full py-2 px-3 text-gray-700 leading-tight focus:outline-none focus:shadow-outline @error('transfer_date') border-red-500 @enderror" name="transfer_date" value="{{ old('transfer_date', date('Y-m-d')) }}" required>
                            @error('transfer_date')
                                <p class="text-red-500 text-xs italic mt-1">{{ $message }}</p>
                            @enderror
                        </div>

                        <div class="mb-4">
                            <label for="receipt_date" class="block text-gray-700 text-sm font-bold mb-2">{{ __('تاريخ الاستلام') }}</label>
                            <input id="receipt_date" type="date" class="shadow appearance-none border rounded w-full py-2 px-3 text-gray-700 leading-tight focus:outline-none focus:shadow-outline @error('receipt_date') border-red-500 @enderror" name="receipt_date" value="{{ old('receipt_date') }}">
                            @error('receipt_date')
                                <p class="text-red-500 text-xs italic mt-1">{{ $message }}</p>
                            @enderror
                        </div>

                        <div class="mb-4">
                            <label for="status" class="block text-gray-700 text-sm font-bold mb-2">{{ __('الحالة') }}</label>
                            <select id="status" class="shadow appearance-none border rounded w-full py-2 px-3 text-gray-700 leading-tight focus:outline-none focus:shadow-outline @error('status') border-red-500 @enderror" name="status" required>
                                <option value="pending" {{ old('status') == 'pending' ? 'selected' : '' }}>{{ __('قيد الانتظار') }}</option>
                                <option value="processing" {{ old('status') == 'processing' ? 'selected' : '' }}>{{ __('قيد المعالجة') }}</option>
                                <option value="completed" {{ old('status') == 'completed' ? 'selected' : '' }}>{{ __('مكتمل') }}</option>
                                <option value="failed" {{ old('status') == 'failed' ? 'selected' : '' }}>{{ __('فشل') }}</option>
                                <option value="canceled" {{ old('status') == 'canceled' ? 'selected' : '' }}>{{ __('ملغي') }}</option>
                            </select>
                            @error('status')
                                <p class="text-red-500 text-xs italic mt-1">{{ $message }}</p>
                            @enderror
                        </div>

                        <div class="mb-4">
                            <label for="notes" class="block text-gray-700 text-sm font-bold mb-2">{{ __('ملاحظات') }}</label>
                            <textarea id="notes" class="shadow appearance-none border rounded w-full py-2 px-3 text-gray-700 leading-tight focus:outline-none focus:shadow-outline @error('notes') border-red-500 @enderror" name="notes" rows="3">{{ old('notes') }}</textarea>
                            @error('notes')
                                <p class="text-red-500 text-xs italic mt-1">{{ $message }}</p>
                            @enderror
                        </div>

                        <div class="flex items-center justify-between">
                            <button type="submit" class="bg-blue-500 hover:bg-blue-700 text-white font-bold py-2 px-4 rounded focus:outline-none focus:shadow-outline">
                                {{ __('إنشاء الحوالة') }}
                            </button>
                            <a href="{{ route('transfers.index') }}" class="inline-block align-baseline font-bold text-sm text-blue-500 hover:text-blue-800">
                                {{ __('إلغاء') }}
                            </a>
                        </div>
                    </form>
                </div>
            </div>
        </div>
    </div>
</x-app-layout>