<?php

use Illuminate\Support\Facades\Route;
use App\Http\Controllers\ClientController;
use App\Http\Controllers\InvoiceController;
use App\Http\Controllers\TransferController;
use App\Http\Controllers\PurchaseController;
use App\Http\Controllers\ReportController;
use App\Http\Controllers\ProfileController;
use App\Http\Controllers\DashboardController;

/*
|--------------------------------------------------------------------------
| Web Routes
|--------------------------------------------------------------------------
|
| Here is where you can register web routes for your application. These
| routes are loaded by the RouteServiceProvider and all of them will
| be assigned to the "web" middleware group. Make something great!
|
*/

// Redirect root to dashboard or login page
Route::get('/', function () {
    return redirect()->route('dashboard');
});

// Authentication required routes
Route::middleware(['auth'])->group(function () {
    // Dashboard
    Route::get('/dashboard', function () {
        // Dashboard data
        $clientCount = \App\Models\Client::count();
        $invoiceCount = \App\Models\Invoice::count();
        $transferCount = \App\Models\Transfer::count();
        $purchaseCount = \App\Models\Purchase::count();
        
        // Recent data
        $recentInvoices = \App\Models\Invoice::with('client')->latest()->take(5)->get();
        $recentTransfers = \App\Models\Transfer::with('invoice.client')->latest()->take(5)->get();
        
        return view('dashboard', compact(
            'clientCount', 
            'invoiceCount', 
            'transferCount', 
            'purchaseCount',
            'recentInvoices',
            'recentTransfers'
        ));
    })->middleware(['auth'])->name('dashboard');
    
    // Client routes
    Route::resource('clients', ClientController::class);
    Route::get('clients/{client}/invoices', [ClientController::class, 'invoices'])->name('clients.invoices');
    
    // Invoice routes
    Route::resource('invoices', InvoiceController::class);
    Route::get('invoices/{invoice}/print', [InvoiceController::class, 'print'])->name('invoices.print');
    Route::post('invoices/{invoice}/add-payment', [InvoiceController::class, 'addPayment'])->name('invoices.add-payment');
    Route::get('invoices/{invoice}/pdf', [InvoiceController::class, 'generatePdf'])->name('invoices.pdf');
    
    // Transfer routes
    Route::resource('transfers', TransferController::class);
    Route::get('transfers/by-status/{status}', [TransferController::class, 'byStatus'])->name('transfers.by-status');
    Route::post('transfers/{transfer}/update-status', [TransferController::class, 'updateStatus'])->name('transfers.update-status');
    
    // Purchase routes
    Route::resource('purchases', PurchaseController::class);
    Route::get('purchases/year/{year}', [PurchaseController::class, 'byYear'])->name('purchases.by-year');
    Route::get('purchases/supplier/{supplier}', [PurchaseController::class, 'bySupplier'])->name('purchases.by-supplier');
    
    // Report routes
    Route::get('reports/sales', [ReportController::class, 'sales'])->name('reports.sales');
    Route::get('reports/purchases', [ReportController::class, 'purchases'])->name('reports.purchases');
    Route::get('reports/inventory', [ReportController::class, 'inventory'])->name('reports.inventory');
    Route::get('reports/client-statement/{client}', [ReportController::class, 'clientStatement'])->name('reports.client-statement');
    Route::get('reports/profit-loss', [ReportController::class, 'profitLoss'])->name('reports.profit-loss');
    
    // Export routes
    Route::get('export/invoices', [InvoiceController::class, 'export'])->name('export.invoices');
    Route::get('export/clients', [ClientController::class, 'export'])->name('export.clients');
    Route::get('export/purchases', [PurchaseController::class, 'export'])->name('export.purchases');
    
    // User profile routes
    Route::get('/profile', [ProfileController::class, 'edit'])->name('profile.edit');
    Route::patch('/profile', [ProfileController::class, 'update'])->name('profile.update');
    Route::delete('/profile', [ProfileController::class, 'destroy'])->name('profile.destroy');
    
    // Settings
    Route::get('/settings', [App\Http\Controllers\SettingController::class, 'edit'])->name('settings.edit');
    Route::patch('/settings', [App\Http\Controllers\SettingController::class, 'update'])->name('settings.update');
});

// Authentication routes (login, register, password reset, etc.)
require __DIR__.'/auth.php';