<!DOCTYPE html>
<html lang="ar" dir="rtl">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>فاتورة <?php echo e($invoice->invoice_number); ?></title>
    <style>
        @page {
            size: A4;
            margin: 0;
        }
        body {
            font-family: Arial, sans-serif;
            margin: 0;
            padding: 0;
            direction: rtl;
        }
        .invoice-container {
            max-width: 800px;
            margin: 0 auto;
            padding: 20px;
        }
        .company-header {
            text-align: center;
            margin-bottom: 20px;
        }
        .company-logo {
            max-width: 150px;
            margin-bottom: 10px;
        }
        .company-name {
            font-size: 22px;
            font-weight: bold;
            margin-bottom: 5px;
        }
        .company-details {
            font-size: 14px;
            color: #555;
        }
        .invoice-title {
            text-align: center;
            font-size: 24px;
            font-weight: bold;
            margin: 20px 0;
        }
        .invoice-meta {
            display: flex;
            justify-content: space-between;
            margin-bottom: 20px;
        }
        .invoice-meta-section {
            width: 48%;
        }
        .meta-table {
            width: 100%;
            border-collapse: collapse;
        }
        .meta-table td {
            padding: 8px;
            border: 1px solid #ddd;
        }
        .meta-table td:first-child {
            width: 40%;
            text-align: left;
            font-weight: bold;
        }
        .items-table {
            width: 100%;
            border-collapse: collapse;
            margin-bottom: 20px;
        }
        .items-table th, .items-table td {
            padding: 10px;
            border: 1px solid #ddd;
            text-align: center;
        }
        .items-table th {
            background-color: #000;
            color: white;
        }
        .totals-section {
            margin-bottom: 30px;
        }
        .totals-table {
            width: 100%;
            border-collapse: collapse;
        }
        .totals-table td {
            padding: 8px;
            border: 1px solid #ddd;
        }
        .totals-table .total-label {
            text-align: right;
            font-weight: bold;
        }
        .totals-table .total-value {
            text-align: left;
        }
        .signatures {
            display: flex;
            justify-content: space-between;
            margin-top: 40px;
            margin-bottom: 20px;
        }
        .signature-section {
            width: 30%;
            text-align: center;
        }
        .signature-label {
            font-weight: bold;
            margin-bottom: 50px;
        }
        .signature-value {
            border-top: 1px solid #000;
            padding-top: 5px;
        }
        .footer {
            margin-top: 50px;
            text-align: center;
            font-size: 14px;
            color: #555;
            border-top: 1px solid #ddd;
            padding-top: 10px;
        }
        .print-actions {
            text-align: center;
            margin: 20px 0;
            display: none;
        }
        @media print {
            .print-actions {
                display: none;
            }
        }
    </style>
</head>
<body>
    <div class="invoice-container">
        <div class="print-actions">
            <button onclick="window.print()">طباعة الفاتورة</button>
            <button onclick="window.location.href='<?php echo e(route('invoices.show', $invoice)); ?>'">العودة</button>
        </div>
        
        <div class="company-header">
            <img src="<?php echo e(asset('images/logo.png')); ?>" alt="شركة البريق الأصفر" class="company-logo">
            <div class="company-name">شركة البريق الأصفر</div>
            <div class="company-details">لتجارة الذهب والمسابك والمجوهرات محدودة المسؤولية</div>
        </div>
        
        <div class="invoice-title">INVOICE</div>
        
        <div class="invoice-meta">
            <div class="invoice-meta-section">
                <table class="meta-table">
                    <tr>
                        <td>رقم الفاتورة:</td>
                        <td><?php echo e($invoice->invoice_number); ?></td>
                    </tr>
                    <tr>
                        <td>تاريخ الفاتورة:</td>
                        <td><?php echo e($invoice->invoice_date->format('Y-m-d')); ?></td>
                    </tr>
                    <tr>
                        <td>نوع الدفع:</td>
                        <td><?php echo e($invoice->payment_type == 'cash' ? 'نقدي' : $invoice->payment_type); ?></td>
                    </tr>
                    <tr>
                        <td>سعر الذهب:</td>
                        <td><?php echo e(number_format($invoice->gold_price, 2)); ?></td>
                    </tr>
                </table>
            </div>
            <div class="invoice-meta-section">
                <table class="meta-table">
                    <tr>
                        <td>اسم الزبون:</td>
                        <td><?php echo e($invoice->client->name); ?></td>
                    </tr>
                    <tr>
                        <td>العنوان:</td>
                        <td><?php echo e($invoice->client->address ?? ''); ?></td>
                    </tr>
                    <tr>
                        <td>رقم الهاتف:</td>
                        <td><?php echo e($invoice->client->phone ?? ''); ?></td>
                    </tr>
                    <tr>
                        <td>رقم الإجازة:</td>
                        <td><?php echo e($invoice->client->license_number ?? ''); ?></td>
                    </tr>
                </table>
            </div>
        </div>
        
        <table class="items-table">
            <thead>
                <tr>
                    <th>ت</th>
                    <th>التفاصيل</th>
                    <th>الوزن</th>
                    <th>العيار</th>
                    <th>الأجرة</th>
                    <th>المجموع</th>
                </tr>
            </thead>
            <tbody>
                <?php $__currentLoopData = $invoice->items; $__env->addLoop($__currentLoopData); foreach($__currentLoopData as $index => $item): $__env->incrementLoopIndices(); $loop = $__env->getLastLoop(); ?>
                <tr>
                    <td><?php echo e($index + 1); ?></td>
                    <td><?php echo e($item->details); ?></td>
                    <td><?php echo e(number_format($item->weight, 3)); ?></td>
                    <td><?php echo e($item->caliber); ?></td>
                    <td><?php echo e(number_format($item->fees, 2)); ?></td>
                    <td><?php echo e(number_format($item->total, 2)); ?></td>
                </tr>
                <?php endforeach; $__env->popLoop(); $loop = $__env->getLastLoop(); ?>
                
                <?php for($i = count($invoice->items); $i < 10; $i++): ?>
                <tr>
                    <td>&nbsp;</td>
                    <td></td>
                    <td></td>
                    <td></td>
                    <td></td>
                    <td></td>
                </tr>
                <?php endfor; ?>
            </tbody>
        </table>
        
        <div style="text-align: center; margin-bottom: 10px;">
            <span>غم عيار 21</span>
            <span style="margin-right: 30px;">مجموع القائمة</span>
        </div>
        
        <div class="totals-section">
            <table class="totals-table">
                <tr>
                    <td class="total-label">مجموع الذهب</td>
                    <td class="total-value"><?php echo e(number_format($invoice->total_gold, 2)); ?></td>
                </tr>
                <tr>
                    <td class="total-label">المجموع الكلي</td>
                    <td class="total-value"><?php echo e(number_format($invoice->grand_total, 2)); ?> د.ع</td>
                </tr>
            </table>
        </div>
        
        <div>
            <table class="totals-table">
                <tr>
                    <td colspan="2">تم الاضافة على حسابكم:-</td>
                </tr>
                <tr>
                    <td>نقد د.ع</td>
                    <td>#VALUE!</td>
                </tr>
                <tr>
                    <td>ذهب</td>
                    <td><?php echo e(number_format($invoice->total_weight, 3)); ?></td>
                </tr>
            </table>
        </div>
        
        <div class="signatures">
            <div class="signature-section">
                <div class="signature-label">توقيع الزبون/المستلم</div>
                <div class="signature-value"><?php echo e($invoice->client_signature ?? '0'); ?></div>
            </div>
            <div class="signature-section">
                <div class="signature-label">الوزن مع الاكياس</div>
                <div class="signature-value">غم</div>
            </div>
            <div class="signature-section">
                <div class="signature-label">توقيع المدير المفوض</div>
                <div class="signature-value"><?php echo e($invoice->authorized_signature ?? 'علي نزار محمد'); ?></div>
            </div>
        </div>
        
        <div class="footer">
            <p>بغداد - شارع النهر - بناية مركز الذهب 110 رقم 16 ط3</p>
            <p>+9647814601639</p>
            <p>ceo@yellowsparkle.co</p>
            <p>www.yellowsparkle.co</p>
        </div>
    </div>

    <script>
        window.onload = function() {
            if (!window.location.search.includes('print=false')) {
                window.print();
            }
        };
    </script>
</body>
</html><?php /**PATH C:\xampp\htdocs\GoldCoMS\resources\views/invoices/print.blade.php ENDPATH**/ ?>